<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Программная (xrandr) яркость</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Аппаратная подсветка</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Экран</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="78"/>
        <location filename="../defaultlook.cpp" line="629"/>
        <location filename="../defaultlook.cpp" line="648"/>
        <location filename="../defaultlook.cpp" line="657"/>
        <location filename="../defaultlook.cpp" line="699"/>
        <location filename="../defaultlook.cpp" line="709"/>
        <location filename="../defaultlook.cpp" line="737"/>
        <location filename="../defaultlook.cpp" line="740"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="32"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настроить панель&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="46"/>
        <location filename="../defaultlook.ui" line="156"/>
        <source>Panel</source>
        <translation>Панель</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="66"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настроить поведение окон и сочетания клавиш&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="80"/>
        <source>Window Manager</source>
        <translation>Оконный менеджер</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="100"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Персонализация рабочего стола&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="114"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="129"/>
        <source>Xfce Settings</source>
        <translation>Настройки Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="320"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Влияет на все панели&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="227"/>
        <location filename="../defaultlook.ui" line="1428"/>
        <source>Affects 1st panel</source>
        <translation>Влияет на первую панель</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="280"/>
        <location filename="../defaultlook.ui" line="1451"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="285"/>
        <location filename="../defaultlook.ui" line="1461"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="204"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Кнопки окон&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <location filename="../defaultlook.ui" line="1446"/>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="259"/>
        <location filename="../defaultlook.ui" line="1456"/>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="164"/>
        <location filename="../defaultlook.ui" line="303"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="310"/>
        <source>Display panel horizontally</source>
        <translation>Горизонтальное расположение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="171"/>
        <source>Display panel vertically</source>
        <translation>Вертикальное расположение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="211"/>
        <source>Restore default panel</source>
        <translation>Вернуть панель по умолчанию</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="181"/>
        <source>Backup current panel configuration</source>
        <translation>Сохранить текущую конфигурацию панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Restore backup panel configuration</source>
        <translation>Восстановить конфигурацию панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="353"/>
        <location filename="../defaultlook.ui" line="405"/>
        <location filename="../defaultlook.ui" line="561"/>
        <location filename="../defaultlook.ui" line="886"/>
        <location filename="../defaultlook.ui" line="893"/>
        <location filename="../defaultlook.ui" line="900"/>
        <location filename="../defaultlook.ui" line="1026"/>
        <location filename="../defaultlook.ui" line="1393"/>
        <location filename="../defaultlook.ui" line="1586"/>
        <location filename="../defaultlook.ui" line="1742"/>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="384"/>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="392"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Значки&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="428"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Исправить поле ввода HexChat для темной темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="435"/>
        <source>Preview</source>
        <translation>Предпросмотр</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="442"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Исправлять некоторые поля веб-сайтов при использовании темной темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="445"/>
        <source>Firefox dark theme tweak</source>
        <translation>Настройка тёмной темы Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="452"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Менеджер окон&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="459"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Темы&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="466"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Приложения&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="486"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Сохранить текущие настройки как набор тем</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="497"/>
        <source>Remove User Theme Set</source>
        <translation>Удалить пользовательскую настройку темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="514"/>
        <source>Theme Options</source>
        <translation>Параметры темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="537"/>
        <source>Undo</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="547"/>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Compositor</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="581"/>
        <source>Transparency and shadow options</source>
        <translation>Параметры прозрачности и теней</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="595"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Править compton.conf в текстовом редакторе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="598"/>
        <source>Edit compton.conf</source>
        <translation>Править compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="648"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Изменение режима VBlank может смягчить некоторые проблемы тиринга. Для подробностей смотрите Справку.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="659"/>
        <source>auto</source>
        <translation>авторежим</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="664"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="669"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="674"/>
        <source>off</source>
        <translation>откл.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="695"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="700"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Композитор Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="705"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="713"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настройки композитора Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="716"/>
        <source>Xfwm Settings</source>
        <translation>Настройки Xfmw</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="727"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Запустить конфигуратор compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="730"/>
        <source>Compton settings</source>
        <translation>Настройки Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="744"/>
        <source>Display</source>
        <translation>Экран</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="752"/>
        <source>Hardware Backlight</source>
        <translation>Аппаратная подсветка</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="759"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Параметры экрана&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="786"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Выберите экран для настроек xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="796"/>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="803"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Сохранить для этого экрана&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="813"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Программная (xrandr) яркость</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="820"/>
        <location filename="../defaultlook.ui" line="917"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="827"/>
        <source>GTK scaling</source>
        <translation>Масштабирование GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>xrandr Scaling</source>
        <translation>Масштабирование xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="943"/>
        <source>Config Options</source>
        <translation>Параметры конфигурации</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="986"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Сбросить на предустановленные действия по правому щелчку в Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="958"/>
        <source>Enable single-click on desktop</source>
        <translation>Задействовать одиночный щелчок на рабочем столе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="951"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Задействовать одиночный щелчок в файловом менеджере Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1013"/>
        <source>Enable Desktop Zoom </source>
        <translation>Включить масштабирование рабочего стола</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="972"/>
        <location filename="../defaultlook.ui" line="1546"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Показывать на панели окна со всех рабочих столов</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="965"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Отключить укорачивание длинных имен на рабочем столе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="993"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Добавить hibernate в меню Выхода из системы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="979"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>примечание: для hibernate необходим swap &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1037"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Показать кнопки действий файлового диалога GTK в нижней части окон</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1047"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1055"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Панель инструментов&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1089"/>
        <location filename="../defaultlook.ui" line="1125"/>
        <source>On</source>
        <translation>Вкл</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1094"/>
        <location filename="../defaultlook.ui" line="1130"/>
        <source>Off</source>
        <translation>Откл.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1099"/>
        <source>On Hover</source>
        <translation>При наведении</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1117"/>
        <location filename="../defaultlook.ui" line="1138"/>
        <source>Autohide</source>
        <translation>Скрывать автоматически</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1145"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Сбросить ВСЕ настройки mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1152"/>
        <location filename="../defaultlook.ui" line="1166"/>
        <location filename="../defaultlook.ui" line="1435"/>
        <source>Placement</source>
        <translation>Размещение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1159"/>
        <source>Reset DefaultDock</source>
        <translation>Сброс дока</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1173"/>
        <source>Toggle desktop icons</source>
        <translation>Значки на Рабочем столе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1180"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Сброс меню Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1321"/>
        <location filename="../defaultlook.ui" line="1553"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Сбросить настройки по умолчанию&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1328"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки дока&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1335"/>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1342"/>
        <source>Toggle icon captions</source>
        <translation>Подписи значков</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1349"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Значки на Рабочем столе&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1356"/>
        <source>Height</source>
        <translation>Высота</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1363"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Добавить элементы по умолчанию к существующему меню fluxbox.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1366"/>
        <source>Upgrade existing menu entries</source>
        <translation>Обновить существующие элементы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1386"/>
        <source>Show Toolbar</source>
        <translation>Показать панель инструментов</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1414"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1469"/>
        <source>Systray Icon Size</source>
        <translation>Размер значка в трее</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>Small</source>
        <translation>Малый</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1490"/>
        <source>Medium</source>
        <translation>Средний</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1495"/>
        <source>Large</source>
        <translation>Большой</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1500"/>
        <source>Larger</source>
        <translation>Крупнее</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1505"/>
        <source>Largest</source>
        <translation>Самый крупный</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1532"/>
        <source>Workspace</source>
        <translation>Рабочее место</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1539"/>
        <source>Enable single-click</source>
        <translation>Использовать одиночный щелчок</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1560"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Сброс настроек KDE/Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1600"/>
        <source>Other</source>
        <translation>Другое</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1667"/>
        <source>Password for administrative tasks:</source>
        <translation>Пароль для задач администрирования:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1615"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Использовать опцию драйвера radeon видео без тиринга</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1629"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-radeon.conf будет скопирован в домашний каталог</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1674"/>
        <source>&amp;User</source>
        <translation>&amp;Пользователь</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1681"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Использовать драйвер Intel вместо драйвера &quot;modesetting&quot; (требуется перезапуск)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1729"/>
        <source>Enable kernel sandbox</source>
        <translation>Задействовать песочницу ядра</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1653"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-intel.conf будет сохранен в домашней директории</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1695"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Сбросить Lightdm (экран логина) к системной теме по умолчанию</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1660"/>
        <source>Use libinput driver for touchpad instead of synaptics touchpad driver (requires restart)</source>
        <translation>Использовать для тачпада драйвер libinput вместо synaptics (требуется перезапуск)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1622"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-amd.conf будет скопирован в домашний каталог</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1608"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Включить монтирование внешних носителей для не-root пользователей</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1688"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Использовать опцию amdgpu видео без тиринга</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1702"/>
        <source>Root</source>
        <translation>Суперпользователь</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1636"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Использовать клиентские декорации окон (CSD) для приложений GTK3 (требуется перезапуск сеанса)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1400"/>
        <source>Manage Tint2 Panel</source>
        <translation>Управление панелью Tint2</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1643"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;требует перезагрузки&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1646"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>Включить адаптеры Bluetooth при загрузке</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1753"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt устанавливает дополнительные «рекомендуемые» пакеты в качестве зависимостей</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1822"/>
        <source>About</source>
        <translation>О приложении</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1833"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1850"/>
        <source>Quit application</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1853"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1860"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--переключатель экрана действует только в Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="628"/>
        <source>About MX Tweak</source>
        <translation>О MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="630"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="631"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Приложение для быстрой доводки штатного оформления</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="633"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="634"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="648"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Лицензия</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Отменить</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="658"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Готово! Может потребоваться перезапуск Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>Plese remove special characters</source>
        <translation>Удалите специальные символы</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>from file name</source>
        <translation>из имени файла</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="710"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Файл уже существует. Выберите другое имя</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="738"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Файл не является tar.xz архивом</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="741"/>
        <source>Archive does not contain a panel config</source>
        <translation>Архив не содержит настройки панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="861"/>
        <source>Panel settings</source>
        <translation>Настройки панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="862"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Ваши настройки панели были сохранены в скрытой папке .restore домашнего каталога (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1548"/>
        <source>settings</source>
        <translation>настройки</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1888"/>
        <source>Choose a theme set</source>
        <translation>Выберите набор темы</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Удалить набор тем пользователя</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Новая настройка темы</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Введите имя для настройки темы</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Кнопки окон</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Внешний вид&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Показывать подписи кнопок</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Показывать плоские кнопки</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Показывать ручку</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Порядок сортировки:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Метка времени</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Сгруппировать название и метку времени</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Заголовок окна</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Сгруппировать название приложения и заголовок окна</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Нет, разрешить перетаскивание</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Поведение&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Группировать окна:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Всегда</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Действие по щелчку средней кнопкой мыши:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Закрыть окно</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Свернуть окно</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Разворачивать свёрнутые окна на текущий рабочий стол</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Отображать рамку окна под курсором мыши</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Переключать окна с помощью колёсика мыши</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Фильтрация&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Показывать окна со всех рабочих мест или видов</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Показывать только свёрнутые окна</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Показывать окна со всех мониторов</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалоговое окно</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Всплывающие окна</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Окна при перетаскивании</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки непрозрачности&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Оформление окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Отображать тени у уменьшенных (dock) окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Отображать тени у всплывающих окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Окна при изменении размеров</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Отображать тени у обычных окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки возможностей&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Показывать превью окна вместо иконок при прокрутке</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Напрямую отображать полноэкранные оверлей окна</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Неактивные окна</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Синхронизировать отрисовку по вертикальной очистке</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Настройки композитора Xfwm</translation>
    </message>
</context>
</TS>